# This file is part of CloudControl.
#
# CloudControl is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CloudControl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with CloudControl.  If not, see <http://www.gnu.org/licenses/>.


""" Bunch of helpers for jobs system.
"""

from threading import Lock


class AutoIncrementCounter(object):

    """ Manage an auto incremented counter.
    """

    def __init__(self, store):
        self._store = store
        self._current = self._store.get_id_counter()
        self._lock = Lock()

    def get(self):
        """ Get a new incremented number.
        """
        with self._lock:
            self._current += 1
            self._store.store_id_counter(self._current)
            return self._current
