# This file is part of CloudControl.
#
# CloudControl is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CloudControl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with CloudControl.  If not, see <http://www.gnu.org/licenses/>.


""" Some helpers for the TQL database.
"""

import time
from datetime import datetime, timedelta


def taggify(value):
    """ Transform any value into a tag value.
    """
    if isinstance(value, bool):
        value = 'yes' if value else 'no'
    elif isinstance(value, datetime):
        value = str(int(time.mktime(value.timetuple())))
    elif isinstance(value, timedelta):
        value = str(value.seconds + value.days * 86400)
    elif isinstance(value, (set, list, tuple)):
        value = ' '.join((str(x) for x in value))
    elif isinstance(value, dict):
        value = ' '.join((':'.join((str(k), str(v))) for k, v in value.iteritems()))
    elif value is None:
        pass
    else:
        value = str(value)

    return value
